normalize_email_policy_domain

Function normalize_email_policy_domain 

pub fn normalize_email_policy_domain(domain: &str) -> Result<String>
Normalizes an exact email domain policy entry.

Errors

Returns an error when the domain is empty, too long, non-ASCII, structurally malformed, or contains characters other than ASCII letters, digits, hyphens, and dots.