pub fn format_copy_name_with_limit(
template: &CopyNameTemplate,
copy_number: u32,
max_len: usize,
) -> StringExpand description
Formats a copy name while keeping the result within max_len UTF-8 bytes.
pub fn format_copy_name_with_limit(
template: &CopyNameTemplate,
copy_number: u32,
max_len: usize,
) -> StringFormats a copy name while keeping the result within max_len UTF-8 bytes.