pub fn normalize_validate_name(name: &str) -> Result<String>Expand description
Normalizes a file or folder name and validates the normalized result.
Errors
Returns an error when the normalized name violates the shared cross-platform filename rules.