CopyNameTemplate

Struct CopyNameTemplate 

pub struct CopyNameTemplate {
    pub base_name: String,
    pub ext: Option<String>,
    pub next_copy_number: u32,
}
Parsed pieces of a filename used when generating copy names.

Fields

base_name: String

Base filename without the extension and generated copy suffix.

ext: Option<String>

Extension including the leading dot, when the name has one.

next_copy_number: u32

Copy number inferred from the input name.